@@ -14,15 +14,33 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
 # 未完成实名认证，不允许此操作。
 AUTHFAILURE_UNREALNAMEAUTHENTICATED = 'AuthFailure.UnRealNameAuthenticated'
 
+# CAM鉴权失败。
+AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
+
+# 不支持该操作。
+AUTHFAILURE_UNSUPPORTEDOPERATION = 'AuthFailure.UnsupportedOperation'
+
+# 操作失败。
+FAILEDOPERATION = 'FailedOperation'
+
+# 云端录制方法不支持。
+FAILEDOPERATION_CRUNSUPPORTMETHOD = 'FailedOperation.CRUnsupportMethod'
+
 # 房间中没有设置混流模板。
 FAILEDOPERATION_MIXSESSIONNOTEXIST = 'FailedOperation.MixSessionNotExist'
 
 # 云API混流模板和SDK混流冲突。
 FAILEDOPERATION_REQUESTREJECTION = 'FailedOperation.RequestRejection'
 
+# 单用户并发过载，请联系我们增大并发路数到合理值。
+FAILEDOPERATION_RESTRICTEDCONCURRENCY = 'FailedOperation.RestrictedConcurrency'
+
 # 房间不存在。
 FAILEDOPERATION_ROOMNOTEXIST = 'FailedOperation.RoomNotExist'
 
@@ -32,11 +50,8 @@ FAILEDOPERATION_SDKAPPIDNOTEXIST = 'FailedOperation.SdkAppIdNotExist'
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
-# 访问后端服务失败。
-INTERNALERROR_BACKENDFAIL = 'InternalError.BackendFail'
-
-# 访问后端服务超时。
-INTERNALERROR_BACKENDTIMEOUT = 'InternalError.BackendTimeOut'
+# 云端录制内部服务错误。
+INTERNALERROR_CRINTERNALERROR = 'InternalError.CRInternalError'
 
 # 数据库查询异常。
 INTERNALERROR_DBERROR = 'InternalError.DBError'
@@ -56,12 +71,12 @@ INTERNALERROR_HTTPPARASEFALIED = 'InternalError.HttpParaseFalied'
 # 接口错误。
 INTERNALERROR_INTERFACEERR = 'InternalError.InterfaceErr'
 
+# 内部错误，请重试。
+INTERNALERROR_INTERNALERROR = 'InternalError.InternalError'
+
 # 不支持的方法。
 INTERNALERROR_METHODERR = 'InternalError.MethodErr'
 
-# 查询秒级监控失败。
-INTERNALERROR_MONITORQUERYERR = 'InternalError.MonitorQueryErr'
-
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -92,6 +107,9 @@ INVALIDPARAMETER_MAINVIDEORIGHTALIGN = 'InvalidParameter.MainVideoRightAlign'
 # 大画面流类型错误。
 INVALIDPARAMETER_MAINVIDEOSTREAMTYPE = 'InvalidParameter.MainVideoStreamType'
 
+# 参数超出范围。
+INVALIDPARAMETER_OUTOFRANGE = 'InvalidParameter.OutOfRange'
+
 # OutputParams参数错误。
 INVALIDPARAMETER_OUTPUTPARAMS = 'InvalidParameter.OutputParams'
 
@@ -104,13 +122,19 @@ INVALIDPARAMETER_PAGESIZE = 'InvalidParameter.PageSize'
 # PageSize超过100。
 INVALIDPARAMETER_PAGESIZEOVERSIZE = 'InvalidParameter.PageSizeOversize'
 
+# 待操作的图片未找到。
+INVALIDPARAMETER_PICTURENOTFOUND = 'InvalidParameter.PictureNotFound'
+
 # 自定义布局参数错误。
 INVALIDPARAMETER_PRESETLAYOUTCONFIG = 'InvalidParameter.PresetLayoutConfig'
 
+# PublishCdnUrls参数校验失败。
+INVALIDPARAMETER_PUBLISHCDNURLS = 'InvalidParameter.PublishCdnUrls'
+
 # 纯音频推流参数错误。
 INVALIDPARAMETER_PUREAUDIOSTREAM = 'InvalidParameter.PureAudioStream'
 
-# 查询范围超过1个小时。
+# 查询范围超过文档限制。
 INVALIDPARAMETER_QUERYSCALEOVERSIZE = 'InvalidParameter.QueryScaleOversize'
 
 # 纯音频录制参数错误。
@@ -131,15 +155,18 @@ INVALIDPARAMETER_SMALLVIDEOLAYOUTPARAMS = 'InvalidParameter.SmallVideoLayoutPara
 # 小画面布局中流类型参数错误。
 INVALIDPARAMETER_SMALLVIDEOSTREAMTYPE = 'InvalidParameter.SmallVideoStreamType'
 
-# 查询开始时间超过24小时。
+# 查询开始时间超过文档限制。
 INVALIDPARAMETER_STARTTIMEEXPIRE = 'InvalidParameter.StartTimeExpire'
 
 # StartTs参数错误。
 INVALIDPARAMETER_STARTTS = 'InvalidParameter.StartTs'
 
-# 查询开始时间不在5天内。
+# 查询开始时间超过文档限制。
 INVALIDPARAMETER_STARTTSOVERSIZE = 'InvalidParameter.StartTsOversize'
 
+# StrRoomId参数错误。
+INVALIDPARAMETER_STRROOMID = 'InvalidParameter.StrRoomId'
+
 # StreamId参数错误。
 INVALIDPARAMETER_STREAMID = 'InvalidParameter.StreamId'
 
@@ -164,6 +191,9 @@ INVALIDPARAMETERVALUE_ROOMID = 'InvalidParameterValue.RoomId'
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 缺少AccessKey参数。
+MISSINGPARAMETER_ACCESSKEY = 'MissingParameter.AccessKey'
+
 # 缺少AppId参数。
 MISSINGPARAMETER_APPID = 'MissingParameter.AppId'
 
@@ -173,6 +203,12 @@ MISSINGPARAMETER_AUDIOENCODEPARAMS = 'MissingParameter.AudioEncodeParams'
 # 转推参数中缺少BizId。
 MISSINGPARAMETER_BIZID = 'MissingParameter.BizId'
 
+# 缺少Bucket参数。
+MISSINGPARAMETER_BUCKET = 'MissingParameter.Bucket'
+
+# 缺少CloudStorage参数。
+MISSINGPARAMETER_CLOUDSTORAGE = 'MissingParameter.CloudStorage'
+
 # 缺少CommId参数。
 MISSINGPARAMETER_COMMID = 'MissingParameter.CommId'
 
@@ -197,6 +233,15 @@ MISSINGPARAMETER_PUBLISHCDNPARAMS = 'MissingParameter.PublishCdnParams'
 # 转推参数中缺少转推目的地址。
 MISSINGPARAMETER_PUBLISHCDNURLS = 'MissingParameter.PublishCdnUrls'
 
+# 缺少RecordMode参数。
+MISSINGPARAMETER_RECORDMODE = 'MissingParameter.RecordMode'
+
+# 缺少RecordParams参数。
+MISSINGPARAMETER_RECORDPARAMS = 'MissingParameter.RecordParams'
+
+# 缺少Region参数。
+MISSINGPARAMETER_REGION = 'MissingParameter.Region'
+
 # 缺少RoomId参数。
 MISSINGPARAMETER_ROOMID = 'MissingParameter.RoomId'
 
@@ -206,23 +251,50 @@ MISSINGPARAMETER_ROOMNUM = 'MissingParameter.RoomNum'
 # 缺少SdkAppId参数。
 MISSINGPARAMETER_SDKAPPID = 'MissingParameter.SdkAppId'
 
+# 缺少SecretKey参数。
+MISSINGPARAMETER_SECRETKEY = 'MissingParameter.SecretKey'
+
 # 缺少startTS_s参数。
 MISSINGPARAMETER_STARTTS = 'MissingParameter.StartTs'
 
+# 缺少StorageParams参数。
+MISSINGPARAMETER_STORAGEPARAMS = 'MissingParameter.StorageParams'
+
 # OutputParams中缺少StreamId参数。
 MISSINGPARAMETER_STREAMID = 'MissingParameter.StreamId'
 
+# 缺少StreamType参数。
+MISSINGPARAMETER_STREAMTYPE = 'MissingParameter.StreamType'
+
+# 缺少TaskId参数。
+MISSINGPARAMETER_TASKID = 'MissingParameter.TaskId'
+
 # 缺少UserId参数。
 MISSINGPARAMETER_USERID = 'MissingParameter.UserId'
 
 # 缺少UserIds参数。
 MISSINGPARAMETER_USERIDS = 'MissingParameter.UserIds'
 
+# 缺少UserSig参数。
+MISSINGPARAMETER_USERSIG = 'MissingParameter.UserSig'
+
+# 缺少Vendor参数。
+MISSINGPARAMETER_VENDOR = 'MissingParameter.Vendor'
+
 # EncodeParams中缺少视频输出参数。
 MISSINGPARAMETER_VIDEOENCODEPARAMS = 'MissingParameter.VideoEncodeParams'
 
+# 资源不足。
+RESOURCEINSUFFICIENT_REQUESTREJECTION = 'ResourceInsufficient.RequestRejection'
+
+# 资源不存在。
+RESOURCENOTFOUND = 'ResourceNotFound'
+
 # 没有操作SdkAppId的权限。
 UNAUTHORIZEDOPERATION_SDKAPPID = 'UnauthorizedOperation.SdkAppId'
 
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
+
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
